@@ -68,7 +68,8 @@ mpris_proxy_call_done (GObject      *object,
 
   if (!(ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (object), res, &error)))
     {
-      g_warning ("Error calling method %s", error->message);
+      if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+        g_warning ("Error calling method %s", error->message);
       g_clear_error (&error);
       return;
     }
@@ -83,6 +84,9 @@ mpris_controller_key (MprisController *self, const gchar *key)
   if (!priv->mpris_client_proxy)
     return FALSE;
 
+  if (g_strcmp0 (key, "Play") == 0)
+    key = "PlayPause";
+
   g_debug ("calling %s over dbus to mpris client %s",
            key, g_dbus_proxy_get_name (priv->mpris_client_proxy));
   g_dbus_proxy_call (priv->mpris_client_proxy,
@@ -97,15 +101,23 @@ mpris_proxy_ready_cb (GObject      *object,
                       GAsyncResult *res,
                       gpointer      user_data)
 {
-  MprisControllerPrivate *priv = MPRIS_CONTROLLER (user_data)->priv;
+  MprisControllerPrivate *priv;
   GError *error = NULL;
+  GDBusProxy *proxy;
 
-  priv->mpris_client_proxy = g_dbus_proxy_new_for_bus_finish (res, &error);
+  proxy = g_dbus_proxy_new_for_bus_finish (res, &error);
 
-  if (!priv->mpris_client_proxy)
-    g_warning ("Error connecting to mpris interface %s", error->message);
+  if (!proxy)
+    {
+      if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+        g_warning ("Error connecting to mpris interface %s", error->message);
+      g_clear_error (&error);
+      return;
+    }
 
-  g_clear_error (&error);
+  priv = MPRIS_CONTROLLER (user_data)->priv;
+  priv->mpris_client_proxy = proxy;
+  priv->connecting = FALSE;
 }
 
 static void
